Date: 03 23, 2002 5:07:13 AM

# singlezap

## Purpose

Perform a single tier reduction. Excise all the nodes in the matched phrase.

## Syntax

singlezap()

## Returns

## Remarks

Useful for things like retokenizing or replacing parse tree nodes with new nodes.

## Example

# Replace the hyphenated "moti-vate" with "motivate".
@POST
singlezap();
@RULES
motivate <- moti \- vate @@

## See Also

singlex, singler, single, noop, POST Actions